@@ -367,7 +367,10 @@ class ClApplication(Application):
                 start_response(HTTP_403, http_resp_headers.items())
                 return [resp]
             if hasattr (params, 'sid'):
-                curThread.lang = service.get_lang(params.sid)
+                curThread.lang = service.get_lang(params.sid, method_name)
+                if "get_methods" in method_name:
+                    with open('/tmp/getlang','a') as f:
+                        f.write(curThread.lang+"\n")
 
         #### logging
             if curThread.client_cert:
